@@ -42,7 +42,9 @@ int main( int argc, char **argv )
     KAboutData aboutData(QStringLiteral("klines"), i18n("Kolor Lines"), QStringLiteral(KLINES_VERSION_STRING),
                          i18n("Kolor Lines - a little game about balls and how to get rid of them"),
                          KAboutLicense::GPL,
-                         i18n("(c) 2000-2015 The KLines Authors"), QString(), QStringLiteral("https://kde.org/applications/games/org.kde.klines"));
+                         i18n("(c) 2000-2015 The KLines Authors"),
+                         QString(),
+                         QStringLiteral("https://apps.kde.org/klines"));
     aboutData.addAuthor(i18n("Roman Merzlyakov"), i18n("Original author"), QStringLiteral("roman@sbrf.barrt.ru"));
     aboutData.addAuthor(i18n("Roman Razilov"), i18n("Rewrite and Extension"), QStringLiteral("Roman.Razilov@gmx.de"));
     aboutData.addAuthor(i18n("Dmitry Suzdalev"), i18n("Rewrite to use QGraphicsView. Current maintainer"), QStringLiteral("dimsuz@gmail.com"));
